Switch to new contact address in copyright comments.

--HG--
branch : HEAD
diff --git a/lib/make_zip_err_str.sh b/lib/make_zip_err_str.sh
old mode 100755
new mode 100644
index d42df49..e51b172
--- a/lib/make_zip_err_str.sh
+++ b/lib/make_zip_err_str.sh
@@ -4,7 +4,7 @@
 #  Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 #
 #  This file is part of libzip, a library to manipulate ZIP archives.
-#  The authors can be contacted at <nih@giga.or.at>
+#  The authors can be contacted at <libzip@nih.at>
 #
 #  Redistribution and use in source and binary forms, with or without
 #  modification, are permitted provided that the following conditions
diff --git a/lib/zip.h b/lib/zip.h
index 9d0d700..adbcbd3 100644
--- a/lib/zip.h
+++ b/lib/zip.h
@@ -6,7 +6,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_add.c b/lib/zip_add.c
index 9702c47..f6bdb2a 100644
--- a/lib/zip_add.c
+++ b/lib/zip_add.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_add_dir.c b/lib/zip_add_dir.c
index 9b3e5dc..493e28d 100644
--- a/lib/zip_add_dir.c
+++ b/lib/zip_add_dir.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_close.c b/lib/zip_close.c
index 5e4cf89..df9c1d1 100644
--- a/lib/zip_close.c
+++ b/lib/zip_close.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_delete.c b/lib/zip_delete.c
index c302fa9..a0545e4 100644
--- a/lib/zip_delete.c
+++ b/lib/zip_delete.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_dirent.c b/lib/zip_dirent.c
index 1a8e9f1..7b95359 100644
--- a/lib/zip_dirent.c
+++ b/lib/zip_dirent.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_entry_free.c b/lib/zip_entry_free.c
index 3dde3de..c50c943 100644
--- a/lib/zip_entry_free.c
+++ b/lib/zip_entry_free.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_entry_new.c b/lib/zip_entry_new.c
index 5d5c048..7059b1b 100644
--- a/lib/zip_entry_new.c
+++ b/lib/zip_entry_new.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_error.c b/lib/zip_error.c
index c6e5aa5..aab7079 100644
--- a/lib/zip_error.c
+++ b/lib/zip_error.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_error_clear.c b/lib/zip_error_clear.c
index 2989bf2..364383e 100644
--- a/lib/zip_error_clear.c
+++ b/lib/zip_error_clear.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_error_get.c b/lib/zip_error_get.c
index 2186c30..6d1c958 100644
--- a/lib/zip_error_get.c
+++ b/lib/zip_error_get.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_error_get_sys_type.c b/lib/zip_error_get_sys_type.c
index de53a1a..6c6f380 100644
--- a/lib/zip_error_get_sys_type.c
+++ b/lib/zip_error_get_sys_type.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_error_strerror.c b/lib/zip_error_strerror.c
index 91c5b83..3d0951c 100644
--- a/lib/zip_error_strerror.c
+++ b/lib/zip_error_strerror.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_error_to_str.c b/lib/zip_error_to_str.c
index 9f8c465..bdba41a 100644
--- a/lib/zip_error_to_str.c
+++ b/lib/zip_error_to_str.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_fclose.c b/lib/zip_fclose.c
index d3d0cf5..8709362 100644
--- a/lib/zip_fclose.c
+++ b/lib/zip_fclose.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_file_error_clear.c b/lib/zip_file_error_clear.c
index 155c5d4..ef6fa10 100644
--- a/lib/zip_file_error_clear.c
+++ b/lib/zip_file_error_clear.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_file_error_get.c b/lib/zip_file_error_get.c
index 4f9f3a4..f20e011 100644
--- a/lib/zip_file_error_get.c
+++ b/lib/zip_file_error_get.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_file_get_offset.c b/lib/zip_file_get_offset.c
index 99e69a7..68f92f1 100644
--- a/lib/zip_file_get_offset.c
+++ b/lib/zip_file_get_offset.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_file_strerror.c b/lib/zip_file_strerror.c
index d8d00f2..9ba70f1 100644
--- a/lib/zip_file_strerror.c
+++ b/lib/zip_file_strerror.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_fopen.c b/lib/zip_fopen.c
index 715bf6b..6e2f724 100644
--- a/lib/zip_fopen.c
+++ b/lib/zip_fopen.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_fopen_index.c b/lib/zip_fopen_index.c
index 179ea98..a330d69 100644
--- a/lib/zip_fopen_index.c
+++ b/lib/zip_fopen_index.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_fread.c b/lib/zip_fread.c
index 7f498d4..3d9d3c2 100644
--- a/lib/zip_fread.c
+++ b/lib/zip_fread.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_free.c b/lib/zip_free.c
index e1c8730..76c3a96 100644
--- a/lib/zip_free.c
+++ b/lib/zip_free.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_get_archive_comment.c b/lib/zip_get_archive_comment.c
index c8d38aa..669eb70 100644
--- a/lib/zip_get_archive_comment.c
+++ b/lib/zip_get_archive_comment.c
@@ -3,7 +3,7 @@
   Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_get_file_comment.c b/lib/zip_get_file_comment.c
index f704061..adace72 100644
--- a/lib/zip_get_file_comment.c
+++ b/lib/zip_get_file_comment.c
@@ -3,7 +3,7 @@
   Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_get_name.c b/lib/zip_get_name.c
index 594a37d..8f5050b 100644
--- a/lib/zip_get_name.c
+++ b/lib/zip_get_name.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_get_num_files.c b/lib/zip_get_num_files.c
index 770a911..1d9baa3 100644
--- a/lib/zip_get_num_files.c
+++ b/lib/zip_get_num_files.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_memdup.c b/lib/zip_memdup.c
index ccf6bfc..641125e 100644
--- a/lib/zip_memdup.c
+++ b/lib/zip_memdup.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_name_locate.c b/lib/zip_name_locate.c
index 65670e5..baa6141 100644
--- a/lib/zip_name_locate.c
+++ b/lib/zip_name_locate.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_new.c b/lib/zip_new.c
index c65ff73..c72a604 100644
--- a/lib/zip_new.c
+++ b/lib/zip_new.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_open.c b/lib/zip_open.c
index 54a9796..2d6590f 100644
--- a/lib/zip_open.c
+++ b/lib/zip_open.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_rename.c b/lib/zip_rename.c
index 511d39f..b7d1247 100644
--- a/lib/zip_rename.c
+++ b/lib/zip_rename.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_replace.c b/lib/zip_replace.c
index b79a6c0..6cdb80c 100644
--- a/lib/zip_replace.c
+++ b/lib/zip_replace.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_set_archive_comment.c b/lib/zip_set_archive_comment.c
index a2286e8..343fa54 100644
--- a/lib/zip_set_archive_comment.c
+++ b/lib/zip_set_archive_comment.c
@@ -3,7 +3,7 @@
   Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_set_file_comment.c b/lib/zip_set_file_comment.c
index 23c48f9..bc1938e 100644
--- a/lib/zip_set_file_comment.c
+++ b/lib/zip_set_file_comment.c
@@ -3,7 +3,7 @@
   Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_set_name.c b/lib/zip_set_name.c
index 8e4144a..5c7da3d 100644
--- a/lib/zip_set_name.c
+++ b/lib/zip_set_name.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_source_buffer.c b/lib/zip_source_buffer.c
index 4b02434..1e9121c 100644
--- a/lib/zip_source_buffer.c
+++ b/lib/zip_source_buffer.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_source_file.c b/lib/zip_source_file.c
index 5a04d9a..bbaea7e 100644
--- a/lib/zip_source_file.c
+++ b/lib/zip_source_file.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_source_filep.c b/lib/zip_source_filep.c
index 5aeae7a..2189eb6 100644
--- a/lib/zip_source_filep.c
+++ b/lib/zip_source_filep.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_source_free.c b/lib/zip_source_free.c
index ebac71e..7a1632f 100644
--- a/lib/zip_source_free.c
+++ b/lib/zip_source_free.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_source_function.c b/lib/zip_source_function.c
index cea39da..91b183c 100644
--- a/lib/zip_source_function.c
+++ b/lib/zip_source_function.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_source_zip.c b/lib/zip_source_zip.c
index 6842f5d..0768027 100644
--- a/lib/zip_source_zip.c
+++ b/lib/zip_source_zip.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_stat.c b/lib/zip_stat.c
index 3de1f67..df1c0b5 100644
--- a/lib/zip_stat.c
+++ b/lib/zip_stat.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_stat_index.c b/lib/zip_stat_index.c
index 0f45a86..60558e4 100644
--- a/lib/zip_stat_index.c
+++ b/lib/zip_stat_index.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_stat_init.c b/lib/zip_stat_init.c
index f6c68c5..133ad30 100644
--- a/lib/zip_stat_init.c
+++ b/lib/zip_stat_init.c
@@ -3,7 +3,7 @@
   Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_strerror.c b/lib/zip_strerror.c
index 0c86df4..9ebee14 100644
--- a/lib/zip_strerror.c
+++ b/lib/zip_strerror.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_unchange.c b/lib/zip_unchange.c
index 2588a9d..ed0d4de 100644
--- a/lib/zip_unchange.c
+++ b/lib/zip_unchange.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_unchange_all.c b/lib/zip_unchange_all.c
index f382429..54a7a0d 100644
--- a/lib/zip_unchange_all.c
+++ b/lib/zip_unchange_all.c
@@ -3,7 +3,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_unchange_archive.c b/lib/zip_unchange_archive.c
index 85df6ba..6378e39 100644
--- a/lib/zip_unchange_archive.c
+++ b/lib/zip_unchange_archive.c
@@ -3,7 +3,7 @@
   Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zip_unchange_data.c b/lib/zip_unchange_data.c
index f8a3f19..6fe89f4 100644
--- a/lib/zip_unchange_data.c
+++ b/lib/zip_unchange_data.c
@@ -5,7 +5,7 @@
   Copyright (C) 1999, 2004 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/lib/zipint.h b/lib/zipint.h
index 66bca7e..f5f7b56 100644
--- a/lib/zipint.h
+++ b/lib/zipint.h
@@ -6,7 +6,7 @@
   Copyright (C) 1999-2007 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/man/libzip.man b/man/libzip.man
index fa75b22..8d35249 100644
--- a/man/libzip.man
+++ b/man/libzip.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/libzip.mdoc b/man/libzip.mdoc
index 707bf95..f329f9e 100644
--- a/man/libzip.mdoc
+++ b/man/libzip.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_add.man b/man/zip_add.man
index 4bd873f..1ede21c 100644
--- a/man/zip_add.man
+++ b/man/zip_add.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_add.mdoc b/man/zip_add.mdoc
index 5acbfe3..114d995 100644
--- a/man/zip_add.mdoc
+++ b/man/zip_add.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_add_dir.man b/man/zip_add_dir.man
index a4dbc11..5472cc0 100644
--- a/man/zip_add_dir.man
+++ b/man/zip_add_dir.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_add_dir.mdoc b/man/zip_add_dir.mdoc
index d211d18..9a1cbc5 100644
--- a/man/zip_add_dir.mdoc
+++ b/man/zip_add_dir.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_close.man b/man/zip_close.man
index d3f9944..3bd4cbf 100644
--- a/man/zip_close.man
+++ b/man/zip_close.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_close.mdoc b/man/zip_close.mdoc
index b518092..80ef877 100644
--- a/man/zip_close.mdoc
+++ b/man/zip_close.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_delete.man b/man/zip_delete.man
index 64d7950..6689e72 100644
--- a/man/zip_delete.man
+++ b/man/zip_delete.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_delete.mdoc b/man/zip_delete.mdoc
index 190547b..8c7b7a2 100644
--- a/man/zip_delete.mdoc
+++ b/man/zip_delete.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_clear.man b/man/zip_error_clear.man
index 35a34b6..4435a6a 100644
--- a/man/zip_error_clear.man
+++ b/man/zip_error_clear.man
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_clear.mdoc b/man/zip_error_clear.mdoc
index 2c543bb..c800bd4 100644
--- a/man/zip_error_clear.mdoc
+++ b/man/zip_error_clear.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_get.man b/man/zip_error_get.man
index 886d854..e5b988b 100644
--- a/man/zip_error_get.man
+++ b/man/zip_error_get.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_get.mdoc b/man/zip_error_get.mdoc
index 911aebc..861e6db 100644
--- a/man/zip_error_get.mdoc
+++ b/man/zip_error_get.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_get_sys_type.man b/man/zip_error_get_sys_type.man
index c53c637..c86e380 100644
--- a/man/zip_error_get_sys_type.man
+++ b/man/zip_error_get_sys_type.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_get_sys_type.mdoc b/man/zip_error_get_sys_type.mdoc
index d2a9ef4..142d296 100644
--- a/man/zip_error_get_sys_type.mdoc
+++ b/man/zip_error_get_sys_type.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_to_str.man b/man/zip_error_to_str.man
index ec763fc..3563b4a 100644
--- a/man/zip_error_to_str.man
+++ b/man/zip_error_to_str.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_error_to_str.mdoc b/man/zip_error_to_str.mdoc
index 4754f4b..2851d9f 100644
--- a/man/zip_error_to_str.mdoc
+++ b/man/zip_error_to_str.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_errors.man b/man/zip_errors.man
index 418991e..0012a52 100644
--- a/man/zip_errors.man
+++ b/man/zip_errors.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_errors.mdoc b/man/zip_errors.mdoc
index a2f1f86..02add36 100644
--- a/man/zip_errors.mdoc
+++ b/man/zip_errors.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_fclose.man b/man/zip_fclose.man
index 3f68d6c..102456f 100644
--- a/man/zip_fclose.man
+++ b/man/zip_fclose.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_fclose.mdoc b/man/zip_fclose.mdoc
index b4809a1..f487877 100644
--- a/man/zip_fclose.mdoc
+++ b/man/zip_fclose.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_file_strerror.man b/man/zip_file_strerror.man
index 1e5ab8a..31d6633 100644
--- a/man/zip_file_strerror.man
+++ b/man/zip_file_strerror.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_file_strerror.mdoc b/man/zip_file_strerror.mdoc
index e56d8af..5875277 100644
--- a/man/zip_file_strerror.mdoc
+++ b/man/zip_file_strerror.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_fopen.man b/man/zip_fopen.man
index 2d48789..9392e78 100644
--- a/man/zip_fopen.man
+++ b/man/zip_fopen.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_fopen.mdoc b/man/zip_fopen.mdoc
index 8b1c814..2237d19 100644
--- a/man/zip_fopen.mdoc
+++ b/man/zip_fopen.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_fread.man b/man/zip_fread.man
index 63d0b91..edae35b 100644
--- a/man/zip_fread.man
+++ b/man/zip_fread.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_fread.mdoc b/man/zip_fread.mdoc
index ce190b3..26f139c 100644
--- a/man/zip_fread.mdoc
+++ b/man/zip_fread.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_archive_comment.man b/man/zip_get_archive_comment.man
index e80c487..08ad66c 100644
--- a/man/zip_get_archive_comment.man
+++ b/man/zip_get_archive_comment.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_archive_comment.mdoc b/man/zip_get_archive_comment.mdoc
index 43f4dfe..01eb348 100644
--- a/man/zip_get_archive_comment.mdoc
+++ b/man/zip_get_archive_comment.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_file_comment.man b/man/zip_get_file_comment.man
index df5531a..dcc6a03 100644
--- a/man/zip_get_file_comment.man
+++ b/man/zip_get_file_comment.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP files.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_file_comment.mdoc b/man/zip_get_file_comment.mdoc
index cf05456..f3cde89 100644
--- a/man/zip_get_file_comment.mdoc
+++ b/man/zip_get_file_comment.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP files.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_name.man b/man/zip_get_name.man
index 06ef649..78c609d 100644
--- a/man/zip_get_name.man
+++ b/man/zip_get_name.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_name.mdoc b/man/zip_get_name.mdoc
index 2965f83..cfc22ce 100644
--- a/man/zip_get_name.mdoc
+++ b/man/zip_get_name.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_num_files.man b/man/zip_get_num_files.man
index 8743eb9..f470c11 100644
--- a/man/zip_get_num_files.man
+++ b/man/zip_get_num_files.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_get_num_files.mdoc b/man/zip_get_num_files.mdoc
index d4da66f..a341123 100644
--- a/man/zip_get_num_files.mdoc
+++ b/man/zip_get_num_files.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_name_locate.man b/man/zip_name_locate.man
index 0d3a54b..a60117c 100644
--- a/man/zip_name_locate.man
+++ b/man/zip_name_locate.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_name_locate.mdoc b/man/zip_name_locate.mdoc
index b8063e0..0134901 100644
--- a/man/zip_name_locate.mdoc
+++ b/man/zip_name_locate.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_open.man b/man/zip_open.man
index b362624..baa4c39 100644
--- a/man/zip_open.man
+++ b/man/zip_open.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_open.mdoc b/man/zip_open.mdoc
index cabafb2..90d9982 100644
--- a/man/zip_open.mdoc
+++ b/man/zip_open.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_rename.man b/man/zip_rename.man
index 5bb475d..35aa4a9 100644
--- a/man/zip_rename.man
+++ b/man/zip_rename.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_rename.mdoc b/man/zip_rename.mdoc
index 92e5b30..bc9383e 100644
--- a/man/zip_rename.mdoc
+++ b/man/zip_rename.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_set_archive_comment.man b/man/zip_set_archive_comment.man
index b7edf7a..57433a5 100644
--- a/man/zip_set_archive_comment.man
+++ b/man/zip_set_archive_comment.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_set_archive_comment.mdoc b/man/zip_set_archive_comment.mdoc
index 87afcd9..1e1b602 100644
--- a/man/zip_set_archive_comment.mdoc
+++ b/man/zip_set_archive_comment.mdoc
@@ -2,7 +2,7 @@
 .\" Copyright (C) 2006-2007 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_set_file_comment.man b/man/zip_set_file_comment.man
index 793c19b..8a9d56e 100644
--- a/man/zip_set_file_comment.man
+++ b/man/zip_set_file_comment.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP files.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_set_file_comment.mdoc b/man/zip_set_file_comment.mdoc
index 0205f6b..872bc56 100644
--- a/man/zip_set_file_comment.mdoc
+++ b/man/zip_set_file_comment.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP files.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_buffer.man b/man/zip_source_buffer.man
index d0ff2e2..df2987a 100644
--- a/man/zip_source_buffer.man
+++ b/man/zip_source_buffer.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_buffer.mdoc b/man/zip_source_buffer.mdoc
index 6f11dd6..02860e6 100644
--- a/man/zip_source_buffer.mdoc
+++ b/man/zip_source_buffer.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_file.man b/man/zip_source_file.man
index 7d66c4b..f3c404a 100644
--- a/man/zip_source_file.man
+++ b/man/zip_source_file.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_file.mdoc b/man/zip_source_file.mdoc
index fd78d88..d5fdd34 100644
--- a/man/zip_source_file.mdoc
+++ b/man/zip_source_file.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_filep.man b/man/zip_source_filep.man
index 3633e16..fee3c11 100644
--- a/man/zip_source_filep.man
+++ b/man/zip_source_filep.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_filep.mdoc b/man/zip_source_filep.mdoc
index 59fd25e..f3d57ec 100644
--- a/man/zip_source_filep.mdoc
+++ b/man/zip_source_filep.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_free.man b/man/zip_source_free.man
index a7838d3..2195790 100644
--- a/man/zip_source_free.man
+++ b/man/zip_source_free.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_free.mdoc b/man/zip_source_free.mdoc
index acaaa1d..3ec3325 100644
--- a/man/zip_source_free.mdoc
+++ b/man/zip_source_free.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_function.man b/man/zip_source_function.man
index 5fc2432..fef0dac 100644
--- a/man/zip_source_function.man
+++ b/man/zip_source_function.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004-2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_function.mdoc b/man/zip_source_function.mdoc
index aa365bb..c2c557f 100644
--- a/man/zip_source_function.mdoc
+++ b/man/zip_source_function.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004-2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_zip.man b/man/zip_source_zip.man
index 5141b55..8a865f8 100644
--- a/man/zip_source_zip.man
+++ b/man/zip_source_zip.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_source_zip.mdoc b/man/zip_source_zip.mdoc
index 5432caa..d3437a7 100644
--- a/man/zip_source_zip.mdoc
+++ b/man/zip_source_zip.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_stat.man b/man/zip_stat.man
index 81b0ae3..82e4e30 100644
--- a/man/zip_stat.man
+++ b/man/zip_stat.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_stat.mdoc b/man/zip_stat.mdoc
index a2a5a9a..c63930f 100644
--- a/man/zip_stat.mdoc
+++ b/man/zip_stat.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_stat_init.man b/man/zip_stat_init.man
index 47eb752..8202c86 100644
--- a/man/zip_stat_init.man
+++ b/man/zip_stat_init.man
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_stat_init.mdoc b/man/zip_stat_init.mdoc
index fac9052..5807891 100644
--- a/man/zip_stat_init.mdoc
+++ b/man/zip_stat_init.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_unchange.man b/man/zip_unchange.man
index d20b1bf..2b10867 100644
--- a/man/zip_unchange.man
+++ b/man/zip_unchange.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_unchange.mdoc b/man/zip_unchange.mdoc
index 337a5d9..7359d89 100644
--- a/man/zip_unchange.mdoc
+++ b/man/zip_unchange.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_unchange_all.man b/man/zip_unchange_all.man
index e5e884e..5edfb33 100644
--- a/man/zip_unchange_all.man
+++ b/man/zip_unchange_all.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_unchange_all.mdoc b/man/zip_unchange_all.mdoc
index 7fb338e..9adaaed 100644
--- a/man/zip_unchange_all.mdoc
+++ b/man/zip_unchange_all.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005, 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_unchange_archive.man b/man/zip_unchange_archive.man
index 9f64f42..08c736b 100644
--- a/man/zip_unchange_archive.man
+++ b/man/zip_unchange_archive.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zip_unchange_archive.mdoc b/man/zip_unchange_archive.mdoc
index 9ecc31f..2b3137c 100644
--- a/man/zip_unchange_archive.mdoc
+++ b/man/zip_unchange_archive.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2006 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zipcmp.man b/man/zipcmp.man
index 6da7d99..d45c04a 100644
--- a/man/zipcmp.man
+++ b/man/zipcmp.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zipcmp.mdoc b/man/zipcmp.mdoc
index 38622b9..74ad5dd 100644
--- a/man/zipcmp.mdoc
+++ b/man/zipcmp.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2003, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zipmerge.man b/man/zipmerge.man
index 20e6f3c..1e27e93 100644
--- a/man/zipmerge.man
+++ b/man/zipmerge.man
@@ -6,7 +6,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/man/zipmerge.mdoc b/man/zipmerge.mdoc
index acabbea..4b99f2c 100644
--- a/man/zipmerge.mdoc
+++ b/man/zipmerge.mdoc
@@ -4,7 +4,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
diff --git a/regress/add_from_buffer.c b/regress/add_from_buffer.c
index fd11f92..d4130dc 100644
--- a/regress/add_from_buffer.c
+++ b/regress/add_from_buffer.c
@@ -5,7 +5,7 @@
   Copyright (C) 1999, 2003, 2005 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/add_from_file.c b/regress/add_from_file.c
index 35e3ba7..5a3e1c9 100644
--- a/regress/add_from_file.c
+++ b/regress/add_from_file.c
@@ -5,7 +5,7 @@
   Copyright (C) 1999, 2003, 2005 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/add_from_filep.c b/regress/add_from_filep.c
index 9c2647f..33b68fa 100644
--- a/regress/add_from_filep.c
+++ b/regress/add_from_filep.c
@@ -5,7 +5,7 @@
   Copyright (C) 1999, 2003, 2005 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/encrypt.c b/regress/encrypt.c
index c36762b..023a32b 100644
--- a/regress/encrypt.c
+++ b/regress/encrypt.c
@@ -5,7 +5,7 @@
   Copyright (C) 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/fread.c b/regress/fread.c
index caa5745..5d95ef2 100644
--- a/regress/fread.c
+++ b/regress/fread.c
@@ -5,7 +5,7 @@
   Copyright (C) 2004, 2005, 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/get_comment.c b/regress/get_comment.c
index 8360eb9..2e22653 100644
--- a/regress/get_comment.c
+++ b/regress/get_comment.c
@@ -5,7 +5,7 @@
   Copyright (C) 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/mkname.c b/regress/mkname.c
index b263f58..ba4452b 100644
--- a/regress/mkname.c
+++ b/regress/mkname.c
@@ -5,7 +5,7 @@
   Copyright (C) 2005 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/name_locate.c b/regress/name_locate.c
index a5596de..7fa8fa6 100644
--- a/regress/name_locate.c
+++ b/regress/name_locate.c
@@ -5,7 +5,7 @@
   Copyright (C) 2005-2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/open.c b/regress/open.c
index 9a2b099..c16a8bf 100644
--- a/regress/open.c
+++ b/regress/open.c
@@ -5,7 +5,7 @@
   Copyright (C) 1999-2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/set_comment_all.c b/regress/set_comment_all.c
index f3af10f..81f7e87 100644
--- a/regress/set_comment_all.c
+++ b/regress/set_comment_all.c
@@ -5,7 +5,7 @@
   Copyright (C) 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/set_comment_localonly.c b/regress/set_comment_localonly.c
index c732378..74887f8 100644
--- a/regress/set_comment_localonly.c
+++ b/regress/set_comment_localonly.c
@@ -5,7 +5,7 @@
   Copyright (C) 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/set_comment_removeglobal.c b/regress/set_comment_removeglobal.c
index 9b850a9..d7862da 100644
--- a/regress/set_comment_removeglobal.c
+++ b/regress/set_comment_removeglobal.c
@@ -5,7 +5,7 @@
   Copyright (C) 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/regress/set_comment_revert.c b/regress/set_comment_revert.c
index 5cdb88d..8a3d523 100644
--- a/regress/set_comment_revert.c
+++ b/regress/set_comment_revert.c
@@ -5,7 +5,7 @@
   Copyright (C) 2006 Dieter Baron and Thomas Klausner
 
   This file is part of libzip, a library to manipulate ZIP archives.
-  The authors can be contacted at <nih@giga.or.at>
+  The authors can be contacted at <libzip@nih.at>
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
diff --git a/man/make_zip_errors.sh b/man/make_zip_errors.sh
index 46349ae..21b5296 100644
--- a/man/make_zip_errors.sh
+++ b/man/make_zip_errors.sh
@@ -6,7 +6,7 @@
 #  Copyright (C) 1999, 2003, 2004, 2005 Dieter Baron and Thomas Klausner
 #
 #  This file is part of libzip, a library to manipulate ZIP archives.
 #  The authors can be contacted at <nih@giga.or.at>
 #
 #  Redistribution and use in source and binary forms, with or without
 #  modification, are permitted provided that the following conditions
@@ -58,7 +58,7 @@
 .\" Copyright (C) 2004, 2005 Dieter Baron and Thomas Klausner
 .\"
 .\" This file is part of libzip, a library to manipulate ZIP archives.
-.\" The authors can be contacted at <nih@giga.or.at>
+.\" The authors can be contacted at <libzip@nih.at>
 .\"
 .\" Redistribution and use in source and binary forms, with or without
 .\" modification, are permitted provided that the following conditions
@@ -6,7 +6,7 @@
 #
 #  This file is part of libzip, a library to manipulate ZIP archives.
-#  The authors can be contacted at <nih@giga.or.at>
+#  The authors can be contacted at <libzip@nih.at>
 #
 #  Redistribution and use in source and binary forms, with or without